function DescriptiveStats(X, sigma, identificationapproach,name,symmetric,cluster_index)
% for approach 1:
% X has 2 columns, initial estimate Zstat, and replication estimate
% normalized by sigma1; sigma is SE2/SE1
% for approach 2:
% X has 1 column, initial estimate unscaled, sigma=sigma1

critval=1.96;
n=length(X);
circlesize=75/sqrt(n);
GREY=[.7 .7 .7];
SLIDE_GREY=[.6 .6 .6];
BLUE=[.4 .4 .8];

if identificationapproach==1
    
    fig=figure('Visible','on',...
        'PaperPosition',[0 0 4 4],...
        'PaperSize',[4 4]);
    
    ll=floor(min(min(X)));
    uu=ceil(max(max(X)));
    
    ax = gca;
    ax.XTick=ll+1:2:uu;
    ax.YTick=ll+1:2:uu;
    line([ll uu],[ll uu],'Color',GREY);
    hold on;
    line([ll uu],[critval critval],'Color',GREY);
    line([critval critval], [ll uu],'Color',GREY);
    line([ll uu],[-critval -critval],'Color',GREY);
    line([-critval -critval], [ll uu],'Color',GREY);
    
    %version with varying circle size:
    %scatter(X(:,1), X(:,2), 40*min((1./sigma.^2),30), BLUE,'filled')
    
    significant=(abs(X(:,1))>critval);
    scatter(X(significant,1), X(significant,2), 3*circlesize, BLUE,'filled')
    scatter(X(~significant,1), X(~significant,2), 3*circlesize, GREY,'filled')
    
    hold off;
    axis([ll uu ll uu]);
    xlabel('Z','FontSize',9);
    ylabel('Z^r','FontSize',9);
    
    axis square
    
elseif  identificationapproach==2
    circlesize=circlesize*4;
    
    significant=(abs(X./sigma)>critval);
    nooutlier=sigma<50; %added to exclude psych outlier
    
    fig=figure('Visible','on',...
        'PaperPosition',[0 0 3 3],...
        'PaperSize',[3 3]);
    
    rangeX=1.1*max(max(abs(X)), max(abs(sigma(nooutlier)))*critval);
    
    axis([-rangeX rangeX 0 rangeX/critval])
    hold on;
    line([0, rangeX],[0, rangeX/critval],'Color',GREY);
    line([-rangeX,0],[rangeX/critval,0],'Color',GREY);
    
    
    scatter(X(~significant&nooutlier), sigma(~significant&nooutlier), circlesize,GREY,'filled');
    scatter(X(significant&nooutlier), sigma(significant&nooutlier), circlesize,BLUE,'filled');
    
    xlabel('X','FontSize',9);
    ylabel('\Sigma','FontSize',9);
    axis square
end
print(fig,'-dpdf', ['../FiguresandTables/' name 'Scatter.pdf'])

close all
circlesize=200/sqrt(n);
if identificationapproach==1
    
    fig=figure('Visible','on',...
        'PaperPosition',[0 0 9 9],...
        'PaperSize',[9 9]);
    
    ll=floor(min(min(X)));
    uu=ceil(max(max(X)));
    
    
    
    ax = gca;
    ax.XTick=ll+1:2:uu;
    ax.YTick=ll+1:2:uu;
    line([ll uu],[ll uu],'Color',SLIDE_GREY,'Linewidth',1.5);
    hold on;
    line([ll uu],[critval critval],'Color',SLIDE_GREY,'Linewidth',1.5);
    line([critval critval], [ll uu],'Color',SLIDE_GREY,'Linewidth',1.5);
    line([ll uu],[-critval -critval],'Color',SLIDE_GREY,'Linewidth',1.5);
    line([-critval -critval], [ll uu],'Color',SLIDE_GREY,'Linewidth',1.5);
    
    %version with varying circle size:
    %scatter(X(:,1), X(:,2), 40*min((1./sigma.^2),30), BLUE,'filled')
    
    significant=(abs(X(:,1))>critval);
    scatter(X(significant,1), X(significant,2), 3*circlesize, BLUE,'filled')
    scatter(X(~significant,1), X(~significant,2), 3*circlesize, SLIDE_GREY,'filled')
    
    hold off;
    axis([ll uu ll uu]);
    xlabel('Z','FontSize',18);
    ylabel('Z^r','FontSize',18);
    
    text(4,1,'A','FontSize',18);
    text(1,4,'B','FontSize',18);
    
    axis square
    
elseif  identificationapproach==2
    circlesize=circlesize*4;
    
    significant=(abs(X./sigma)>critval);
    nooutlier=sigma<50; %added to exclude psych outlier
    
    fig=figure('Visible','on',...
        'PaperPosition',[0 0 9 9],...
        'PaperSize',[9 9]);
    
    rangeX=1.1*max(max(abs(X)), max(abs(sigma(nooutlier)))*critval);
    
    axis([-rangeX rangeX 0 rangeX/critval])
    hold on;
    line([0, rangeX],[0, rangeX/critval],'Color',SLIDE_GREY,'Linewidth',1.5);
    line([-rangeX,0],[rangeX/critval,0],'Color',SLIDE_GREY,'Linewidth',1.5);
    
    
    scatter(X(~significant&nooutlier), sigma(~significant&nooutlier), circlesize,SLIDE_GREY,'filled');
    scatter(X(significant&nooutlier), sigma(significant&nooutlier), circlesize,BLUE,'filled');
    
    
    xlabel('X','FontSize',18);
    ylabel('\Sigma','FontSize',18);
    axis square
end

print(fig,'-dpdf', ['../FiguresandTables/' name 'SlidesScatter.pdf'])


%%
%Histograms of Z statistics


if identificationapproach==2
    fig=figure('Visible','on',...
        'PaperPosition',[0 0 6 2.5],...
        'PaperSize',[6 2.5])
    circlesize=50/sqrt(n);
    
    
    subplot(1,2,2)
    circlesize=circlesize*4;
    
    significant=(abs(X./sigma)>critval);
    nooutlier=sigma<50; %added to exclude psych outlier
    
    rangeX=1.1*max(max(abs(X)), max(abs(sigma(nooutlier)))*critval);
    
    axis([-rangeX rangeX 0 rangeX/critval])
    hold on;
    line([0, rangeX],[0, rangeX/critval],'Color',GREY);
    line([-rangeX,0],[rangeX/critval,0],'Color',GREY);
    
    
    scatter(X(~significant&nooutlier), sigma(~significant&nooutlier), circlesize,GREY,'filled');
    scatter(X(significant&nooutlier), sigma(significant&nooutlier), circlesize,BLUE,'filled');
    
    xlabel('X','FontSize',9);
    ylabel('\Sigma','FontSize',9);
    axis square
    
    print(fig,'-dpdf', ['../FiguresandTables/' name 'CombinedScatter.pdf'])
    
    
    
    subplot(1,2,1)
    
    if identificationapproach==1
        Zuse=Z(:,1)
    elseif identificationapproach==2
        Zuse=X./sigma;
        if max(abs(Zuse))>10
            Zuse(abs(Zuse)>6)=[];
        end
    end
    
    ll=floor(min(Zuse));
    lleven=floor(ll/2)*2;
    uu=ceil(max(Zuse));

    if symmetric==0
        if n>=30
            uu2=ceil((uu-.36)/.32)*.32+.36;
            ll2=floor((ll+.36)/.32)*.32-.36;
            edges=[ll2:.32:-.36 0 .36:.32:uu2];
        else
            uu2=ceil((uu-.68)/.64)*.64+.68;
            ll2=floor((ll+.68)/.64)*.64-.68;
            edges=[ll2:.64:-.68 0 .68:.64:uu2];
        end
    elseif symmetric==1
        if n>=30
            uu2=ceil((uu-.36)/.32)*.32+.36;
            edges=[0 .36:.32:1.64 1.96:.32:uu2];
        else
            uu2=ceil((uu-.68)/.64)*.64+.68;
            edges=[0 .68:.64:uu2]
        end
    end
    
    
    hold off
    h=histogram(Zuse,edges,'normalization','probability');
    h.FaceColor = BLUE;
    h.FaceAlpha = 1;
    hold on
    axis([min(edges) max(edges) 0 max(h.Values)*1.1]);
    if symmetric==0
        L1=line([-1.96, -1.96],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-');
        L2=line([0, 0],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-.');
        line([1.96, 1.96],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-');
        %line([1.64, 1.64],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle',':');
        xlabel('X/\Sigma','FontSize',9);
        ylabel('Density','FontSize',9)
        %l=legend([L1 L2],'|Z|=1.96','|Z|=1.64','Location','NW')
    elseif symmetric==1
        line([1.96, 1.96],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-');
        %line([1.64, 1.64],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle',':');
        xlabel('|X|/\Sigma','FontSize',9);
        ylabel('Density','FontSize',9)
        %l=legend([L1 L2],'W=1.96','W=1.64','Location','NW')
    end
    ax = gca;
    ax.XTick=lleven:2:uu;
    box off
    h.EdgeColor = 'none';
    axis square
    print(fig,'-dpdf', ['../FiguresandTables/' name 'ScatterHist.pdf'])
end


%%
%Meta-regression estimates
if identificationapproach==2&symmetric==0
    
    R=[ones(length(X),1) sigma];
    betahat=(R'*R)^-1*R'*X;
    ehat=X-R*betahat;
    Sigma_base=R.*repmat(ehat,1,size(R,2));
    Sigma=Clustered_covariance_estimate(Sigma_base,cluster_index);
    Vhat=n*(R'*R)^-1*Sigma*(R'*R)^-1;
    se_robust=diag(Vhat).^.5;
    MetaRegressionTable(betahat,se_robust,name,0)
    
    R=[ones(length(X),1) sigma.^-1];
    gammahat=(R'*R)^-1*R'*(X./sigma);
    ehat=X./sigma-R*gammahat;
    Sigma_base=R.*repmat(ehat,1,size(R,2));
    Sigma=Clustered_covariance_estimate(Sigma_base,cluster_index);
    Vhat=n*(R'*R)^-1*Sigma*(R'*R)^-1;
    se_robust=diag(Vhat).^.5;
    MetaRegressionTable(gammahat,se_robust,name,1)
end

end