function DescriptiveStatsCombined(X_rep,X_meta,sigma_meta,name,symmetric)
% X_rep has 2 columns, initial estimate Zstat, and replication estimate
% normalized by sigma1; sigma is SE2/SE1
% X_meta has 1 column, initial estimate unscaled, sigma_meta=sigma1

critval=1.96;
n=length(X_rep);
circlesize=50/sqrt(n);
GREY=[.7 .7 .7];
SLIDE_GREY=[.6 .6 .6];
BLUE=[.4 .4 .8];

fig=figure('Visible','on',...
    'PaperPosition',[0 0 6 2.5],...
    'PaperSize',[6 2.5])

subplot(1,2,1)
ll=floor(min(min(X_rep)));
uu=ceil(max(max(X_rep)));

ax = gca;
ax.XTick=ll+1:2:uu;
ax.YTick=ll+1:2:uu;
line([ll uu],[ll uu],'Color',GREY);
hold on;
line([ll uu],[critval critval],'Color',GREY);
line([critval critval], [ll uu],'Color',GREY);
line([ll uu],[-critval -critval],'Color',GREY);
line([-critval -critval], [ll uu],'Color',GREY);

%version with varying circle size:
%scatter(X(:,1), X(:,2), 40*min((1./sigma.^2),30), BLUE,'filled')

significant=(abs(X_rep(:,1))>critval);
scatter(X_rep(significant,1), X_rep(significant,2), 3*circlesize, BLUE,'filled')
scatter(X_rep(~significant,1), X_rep(~significant,2), 3*circlesize, GREY,'filled')

hold off;
axis([ll uu ll uu]);
xlabel('W','FontSize',9);
ylabel('W^r','FontSize',9);

%     text(4,1,'A','FontSize',9);
%     text(1,4,'B','FontSize',9);


axis square

%%

subplot(1,2,2)
circlesize=circlesize*4;

significant=(abs(X_meta./sigma_meta)>critval);
nooutlier=sigma_meta<50; %added to exclude psych outlier

rangeX=1.1*max(max(abs(X_meta)), max(abs(sigma_meta(nooutlier)))*critval);

axis([0 rangeX 0 rangeX/critval])
hold on;
line([0, rangeX],[0, rangeX/critval],'Color',GREY);
%line([-rangeX,0],[rangeX/critval,0],'Color',GREY);


scatter(X_meta(~significant&nooutlier), sigma_meta(~significant&nooutlier), circlesize,GREY,'filled');
scatter(X_meta(significant&nooutlier), sigma_meta(significant&nooutlier), circlesize,BLUE,'filled');


xlabel('|X|','FontSize',9);
ylabel('\Sigma','FontSize',9);
axis square

print(fig,'-dpdf', ['../FiguresandTables/' name 'CombinedScatter.pdf'])



%%
%Add histogram to plot

fig=figure('Visible','on',...
    'PaperPosition',[0 0 6 1.75],...
    'PaperSize',[6 1.75])
circlesize=30/sqrt(n);

subplot(1,3,2)
ll=floor(min(min(X_rep)));
uu=ceil(max(max(X_rep)));

ax = gca;
ax.XTick=ll+1:2:uu;
ax.YTick=ll+1:2:uu;
line([ll uu],[ll uu],'Color',GREY);
hold on;
line([ll uu],[critval critval],'Color',GREY);
line([critval critval], [ll uu],'Color',GREY);
line([ll uu],[-critval -critval],'Color',GREY);
line([-critval -critval], [ll uu],'Color',GREY);

%version with varying circle size:
%scatter(X(:,1), X(:,2), 40*min((1./sigma.^2),30), BLUE,'filled')

significant=(abs(X_rep(:,1))>critval);
scatter(X_rep(significant,1), X_rep(significant,2), 3*circlesize, BLUE,'filled')
scatter(X_rep(~significant,1), X_rep(~significant,2), 3*circlesize, GREY,'filled')

hold off;
axis([ll uu ll uu]);
xlabel('W','FontSize',9);
ylabel('W^r','FontSize',9);

%     text(4,1,'A','FontSize',9);
%     text(1,4,'B','FontSize',9);


axis square

%%

subplot(1,3,3)
circlesize=circlesize*4;

significant=(abs(X_meta./sigma_meta)>critval);
nooutlier=sigma_meta<50; %added to exclude psych outlier

rangeX=1.1*max(max(abs(X_meta)), max(abs(sigma_meta(nooutlier)))*critval);

axis([0 rangeX 0 rangeX/critval])
hold on;
line([0, rangeX],[0, rangeX/critval],'Color',GREY);
%line([-rangeX,0],[rangeX/critval,0],'Color',GREY);


scatter(X_meta(~significant&nooutlier), sigma_meta(~significant&nooutlier), circlesize,GREY,'filled');
scatter(X_meta(significant&nooutlier), sigma_meta(significant&nooutlier), circlesize,BLUE,'filled');


xlabel('|X|','FontSize',9);
ylabel('\Sigma','FontSize',9);
axis square
ll=floor(min(X_rep(:,1)));
lleven=min(floor(min(X_rep(:,1)/2))*2,0);
uu=ceil(max(X_rep(:,1)));

subplot(1,3,1)
    if symmetric==0
        if n>=30
            uu2=ceil((uu-.36)/.32)*.32+.36;
            ll2=floor((ll+.36)/.32)*.32-.36;
            edges=[ll2:.32:-.36 0 .36:.32:uu2];
        else
            uu2=ceil((uu-.68)/.64)*.64+.68;
            ll2=floor((ll+.68)/.64)*.64-.68;
            edges=[ll2:.64:-.68 0 .68:.64:uu2];
        end
    elseif symmetric==1
        if n>=30
            uu2=ceil((uu-.36)/.32)*.32+.36;
            edges=[0 .36:.32:1.64 1.96:.32:uu2];
        else
            uu2=ceil((uu-.68)/.64)*.64+.68;
            edges=[0 .68:.64:uu2];
        end
    end

Zuse=X_meta./sigma_meta;

hold off
h=histogram(Zuse,edges,'normalization','probability');
h.FaceColor = BLUE;
h.FaceAlpha = 1;
hold on
axis([min(edges) max(edges) 0 max(h.Values)*1.1]);
if symmetric==0
    L1=line([-1.96, -1.96],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-');
    line([1.96, 1.96],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-');
    xlabel('X/\Sigma','FontSize',9);
    ylabel('Density','FontSize',9)
    %l=legend([L1 L2],'|Z|=1.96','|Z|=1.64','Location','NW')
elseif symmetric==1
    line([1.96, 1.96],[0, max(h.Values)*1.1],'Color',GREY,'Linewidth',1,'Linestyle','-');
    xlabel('W','FontSize',9);
    ylabel('Density','FontSize',9)
    %l=legend([L1 L2],'W=1.96','W=1.64','Location','NW')
end
%l.FontSize=9;

ax = gca;
set(ax, 'XAxisLocation', 'origin')
set(ax, 'YAxisLocation', 'origin')
ax.XTick=lleven:2:uu;
%ax.LineWidth=10;
box off
h.EdgeColor = 'none';
axis square




print(fig,'-dpdf', ['../FiguresandTables/' name 'CombinedScatterHist.pdf'])
end