clear
rng(1)
gamma_grid=-7:.05:7;
omega_grid=-8:.05:8;

%set cutoffs for pretest and test of parameter
omega_cutoff=1.96;
gamma_cutoff=1.96;

%Set number of simulation draws
nsims=10^5;
%Set covariance matrix of estimates
Sigma=[4 -2; -2 4];
sigma_G=Sigma(2,2)^0.5;
sigma_L=Sigma(1,1)^0.5;
%Set parameters of publication probbility
p11=1;
p10=0.1;
p01=0.1;
p00=0.01;

%Take random draws
draws=randn(nsims,2);
draws=draws*Sigma^0.5;
pdraws=rand(nsims,1);

pvec=[p11 p10 p01 p00]';

G_med_store=zeros(length(omega_grid),length(gamma_grid));
G_med_bias_store=zeros(length(omega_grid),length(gamma_grid));
gamma_coverage_store=zeros(length(omega_grid),length(gamma_grid));
for m1=1:length(omega_grid)
    for m2=1:length(gamma_grid)
        omega=omega_grid(m1)*sigma_L;
        gamma=gamma_grid(m2)*sigma_G;
        X=draws;
        X(:,1)=X(:,1)+omega;
        X(:,2)=X(:,2)+gamma;
        
        X_dummies(:,1)=(abs(X(:,1)/sigma_L)<omega_cutoff).*(abs(X(:,2)/sigma_G)>=gamma_cutoff);
        X_dummies(:,2)=(abs(X(:,1)/sigma_L)<omega_cutoff).*(abs(X(:,2)/sigma_G)<gamma_cutoff);
        X_dummies(:,3)=(abs(X(:,1)/sigma_L)>=omega_cutoff).*(abs(X(:,2)/sigma_G)>=gamma_cutoff);
        X_dummies(:,4)=(abs(X(:,1)/sigma_L)>=omega_cutoff).*(abs(X(:,2)/sigma_G)<gamma_cutoff);
        p=X_dummies*pvec;
        
        keep_ind=pdraws<=p;
        X=X(keep_ind==1,:);
        
        G_med_store(m1,m2)=median(X(:,2));
        G_med_bias_store(m1,m2)=median(X(:,2))-gamma;
        gamma_coverage_store(m1,m2)=mean((abs(X(:,2)-gamma)/sigma_G)<=gamma_cutoff);
    end
end



%%
bias_plot_levels=[-4:.1:4];
coverage_plot_levels=[0.4:0.01:1];

%create colormap
POSITIVE=[.4 .2 .2];
NEGATIVE=[.2 .2 .4];
WHITE=[1 1 1];

scale=linspace(0,1,64)';

posvaluemap=scale*WHITE + (1-scale)*NEGATIVE;
negvaluemap=scale*POSITIVE + (1-scale)*WHITE;
colorMap = [posvaluemap; negvaluemap];
colorMapCoverage=colorMap([64-54:64 64:3:64+5*3] ,:)

%%
close all
fig=figure('Visible','on',...
      'PaperPosition',[0 0 10 8],...
      'PaperSize',[10 8]);
contourf(gamma_grid,omega_grid,G_med_bias_store/sigma_G,bias_plot_levels,'Linestyle','none');
%imagesc(gamma_grid,omega_grid,G_med_bias_store);
set(gcf, 'colormap', colorMap)
 hold on
colorbar
xlabel('\gamma/\sigma_G','FontSize',24)
ylabel('\lambda/\sigma_L','FontSize',24)
title('Scaled median bias','FontSize',24) 
hold off
print(fig,'-dpdf', '../../../FiguresandTables/DiffinDiff_MedianBias.pdf')

%%
fig=figure('Visible','on',...
      'PaperPosition',[0 0 10 8],...
      'PaperSize',[10 8]);
contourf(gamma_grid,omega_grid,gamma_coverage_store,coverage_plot_levels,'Linestyle','none');
 set(gcf, 'colormap', colorMapCoverage)
 hold on
caxis([0.4, 1]) 
colorbar
xlabel('\gamma/\sigma_G','FontSize',24)
ylabel('\lambda/\sigma_L','FontSize',24)
title('Coverage probability','FontSize',24) 
hold off
print(fig,'-dpdf', '../../../FiguresandTables/DiffinDiff_Coverage.pdf')

