function cdf=Step_function_multivariate_normal_cdf(X,v,gamma,Sigma,betap,partion_stack,u_stack)
%arguments:
%X: point at which to evaluate cdf
%v: vector which indicates linear combination of parameters of interest
%gamma: value for parameter of interest
%Sigma: variance-covariance matrix of X
%betap: coefficient vector for step function p, in increasing order
%partion_stack: cell array with elements containing matrices which indicate
%bounds of different cells in partition (matrix \Gamma in the notation of
%Taylor et al)
%betap: vector of publication probabilities for different elements in
%partion (should be same size as partion_stack).

G=v'*X;
sigma_G=(v'*Sigma*v)^.5;

rho=zeros(size(partion_stack{1,1},1),length(partion_stack));
check_vec=zeros(length(partion_stack),1);
V_lo=zeros(length(partion_stack),1);
V_up=zeros(length(partion_stack),1);
V_0=zeros(length(partion_stack),1);
for k=1:length(partion_stack)
    Xi=partion_stack{k};
    u=u_stack{k};
    check_vec(k)=min(Xi*X-u)>=0;
    rho(:,k)=Xi*Sigma*v/(v'*Sigma*v);
    V0_base=u-Xi*X;
    V_base=(V0_base+rho(:,k)*G)./rho(:,k);
    if sum(rho(:,k)>0)>0
        V_lo(k)=max(V_base(rho(:,k)>0));
    else
        V_lo(k)=-inf;
    end
    
    if sum(rho(:,k)<0)>0
        V_up(k)=min(V_base(rho(:,k)<0));
    else
        V_up(k)=-inf;
    end
    
    if sum(rho(:,k)==0)>0
        V_0(k)=max(V0_base(rho(:,k)==0));
    else
        V_0(k)=-inf;
    end
    
end

%Calculate denominator in cdf
denominator=0;
for k=1:length(partion_stack)
    if V_up(k)>=V_lo(k)
        denominator=denominator+(V_0(k)<=0)*(normcdf((V_up(k)-gamma)/sigma_G)-normcdf((V_lo(k)-gamma)/sigma_G))*betap(k);
    end
end

%Calculate numerator in cdf
numerator=0;
for k=1:length(partion_stack)
    if V_up(k)>=V_lo(k)
        G_truncate=max(V_lo(k),min(V_up(k),G));
        numerator=numerator+(V_0(k)<=0)*(normcdf((G_truncate-gamma)/sigma_G)-normcdf((V_lo(k)-gamma)/sigma_G))*betap(k);
    end
end

%Evaluate cdf
cdf=numerator/denominator;
end

