clear

%set cutoffs for pretest and test of parameter
omega_cutoff=1.96;
gamma_cutoff=1.96;

%Set covariance matrix of estimates
Sigma=[4 -2; -2 4];

%Set grid of values to consider
l_grid=-7:.05:7;
g_grid=-8:.05:8;

%Set parameter of interest
v=[0;1];

%Coverage for equal-tailed confidence set is 1-alpha
alpha=0.05;

sigma_G=Sigma(2,2)^.5;
sigma_L=Sigma(1,1)^.5;

%Set parameters of publication probability.  Here assume that joint
%publication probability is product of marginal publication probabilities
%determined for each parameter seperately
p_high=1;
p_low=0.1;

cutoff_vec_w=[-inf -omega_cutoff*sigma_L omega_cutoff*sigma_L inf];
cutoff_vec_g=[-inf -gamma_cutoff*sigma_G gamma_cutoff*sigma_G inf];
cutoff_mat=[cutoff_vec_w' cutoff_vec_g'];
probability_vec_L=[p_low p_high p_low];
probability_vec_G=[p_high p_low p_high];
probability_mat=[probability_vec_L' probability_vec_G'];

%Calculate inputs for truncated normal cdf
[betap,partion_stack,u_stack] = product_partition_calculate(cutoff_mat,probability_mat);

Gamma_U_store=zeros(length(l_grid),length(g_grid));
Gamma_L_store=zeros(length(l_grid),length(g_grid));
Gamma_M_store=zeros(length(l_grid),length(g_grid));
Gamma_U_adjustment_store=zeros(length(l_grid),length(g_grid));
Gamma_L_adjustement_store=zeros(length(l_grid),length(g_grid));
Gamma_M_adjustement_store=zeros(length(l_grid),length(g_grid));
for n1=1:length(l_grid)
    parfor n2=1:length(g_grid)
        X=[l_grid(n1)*sigma_L;g_grid(n2)*sigma_G];
        g_U=@(gamma)(alpha/2-Step_function_multivariate_normal_cdf(X,v,gamma,Sigma,betap,partion_stack,u_stack)).^2;
        g_L=@(gamma)(1-alpha/2-Step_function_multivariate_normal_cdf(X,v,gamma,Sigma,betap,partion_stack,u_stack)).^2;
        g_M=@(gamma)(1/2-Step_function_multivariate_normal_cdf(X,v,gamma,Sigma,betap,partion_stack,u_stack)).^2;
        
        gamma_U=fminsearch(g_U,X(2));
        gamma_L=fminsearch(g_L,X(2));
        gamma_M=fminsearch(g_M,X(2));
        
        Gamma_U_store(n1,n2)=gamma_U;
        Gamma_L_store(n1,n2)=gamma_L;
        Gamma_M_store(n1,n2)=gamma_M;
        
        Gamma_U_adjustment_store(n1,n2)=gamma_U-g_grid(n2)*sigma_G-1.96*sigma_G;
        Gamma_L_adjustment_store(n1,n2)=gamma_L-g_grid(n2)*sigma_G+1.96*sigma_G;
        Gamma_M_adjustment_store(n1,n2)=gamma_M-g_grid(n2)*sigma_G;
    end
end


%%
plot_levels=[-4:.02:4];


%create colormap
POSITIVE=[.4 .2 .2];
NEGATIVE=[.2 .2 .4];
WHITE=[1 1 1];

scale=linspace(0,1,64)';

posvaluemap=scale*WHITE + (1-scale)*NEGATIVE;
negvaluemap=scale*POSITIVE + (1-scale)*WHITE;
colorMap = [posvaluemap; negvaluemap];
colorMapCoverage=colorMap([64-46:64 64:5:64+4*5] ,:)

%%



close all
fig=figure('Visible','on',...
    'PaperPosition',[0 0 10 8],...
    'PaperSize',[10 8]);
contourf(g_grid,l_grid,Gamma_M_adjustment_store/sigma_G,plot_levels,'Linestyle','none');
set(gcf, 'colormap', colorMap)
hold on
caxis([-2.5 2.5]) 
colorbar
xlabel('G/\sigma_G','FontSize',24)
ylabel('L/\sigma_L','FontSize',24)
title('Scaled point estimate adjustment','FontSize',24)
hold off
print(fig,'-dpdf', '../../../FiguresandTables/DiffinDiff_MedianUnbiased.pdf')

%%
fig2=figure('Visible','on',...
    'PaperPosition',[0 0 10 8],...
    'PaperSize',[10 8]);
contourf(g_grid,l_grid,Gamma_L_adjustment_store/sigma_G,plot_levels,'Linestyle','none');
set(gcf, 'colormap', colorMap)
hold on
caxis([-2.5 2.5]) 
colorbar
xlabel('G/\sigma_G','FontSize',16)
ylabel('L/\sigma_L','FontSize',16)
title('Scaled lower confidence bound adjustment','FontSize',16)
hold off
print(fig2,'-dpdf', '../../../FiguresandTables/DiffinDiff_Lower.pdf')

fig3=figure('Visible','on',...
    'PaperPosition',[0 0 10 8],...
    'PaperSize',[10 8]);
contourf(g_grid,l_grid,Gamma_U_adjustment_store/sigma_G,plot_levels,'Linestyle','none');
set(gcf, 'colormap', colorMap)
hold on
caxis([-2.5 2.5]) 
colorbar
xlabel('G/\sigma_G','FontSize',16)
ylabel('L/\sigma_L','FontSize',16)
title('Scaled upper confidence bound adjustment','FontSize',16)
hold off
print(fig3,'-dpdf', '../../../FiguresandTables/DiffinDiff_Upper.pdf')

%%
rejection=(Gamma_L_store>=0)+(Gamma_U_store<=0);

fig4=figure('Visible','on',...
    'PaperPosition',[0 0 10 8],...
    'PaperSize',[10 8]);
contourf(g_grid,l_grid,1-rejection,'Linestyle','none');
set(gcf, 'colormap', [(.4*NEGATIVE +.6*WHITE); WHITE])
hold on
%colorbar
xlabel('G/\sigma_G','FontSize',24)
ylabel('L/\sigma_L','FontSize',24)
title('Rejection Region for two-sided test of \gamma=0','FontSize',24)
hold off
print(fig4,'-dpdf', '../../../FiguresandTables/DiffinDiff_Rejection.pdf')