close all
seed=4;
lambdabar=1;
tau=1;
n=150;

Lambdastar=lambdabar + tau*randn(n,1);
sigma=sqrt(sum(randn(n,3).^2,2)/3);


circlesize=30;
circlesize_paper=20;
critval=1.96;

GREY=[.7 .7 .7];
SLIDE_GREY=[.6 .6 .6];
BLUE=[.4 .4 .8];

%%
%Illustrating replication approach
%Used in paper
rng(seed)
X= Lambdastar + randn(n,1);
Xr = Lambdastar +   randn(n,1);
significant=(abs(X)>critval);
D=(rand(n,1) < 0.1 + 0.9 * significant);


fig=figure('Visible','on',...
      'PaperPosition',[0 0 6 2.5],...
      'PaperSize',[6 2.5])
subplot(1,2,1)
scatter(X(significant), Xr(significant), circlesize_paper, BLUE,'filled');
    hold on;  
scatter(X(~significant), Xr(~significant), circlesize_paper,GREY,'filled'); 

ax = gca;
axis([-3 5 -3 5])
ax.XTick=[-1.96 0 1.96];
ax.YTick=[-1.96 0 1.96];
line([-3 5],[-3,5],'Color',GREY);
line([-3 5],[critval critval],'Color',GREY);
line([-3 5],[-critval -critval],'Color',GREY);
line([critval critval], [-3 5],'Color',GREY);
line([-critval -critval], [-3 5],'Color',GREY);
xlabel('Z^*','FontSize',9);
ylabel('Z^{r*}','FontSize',9); 
axis square

subplot(1,2,2)
scatter(X(significant), Xr(significant), circlesize_paper, BLUE,'filled');
    hold on;  
scatter(X(~significant & D), Xr(~significant & D), circlesize_paper,GREY,'filled');  
ax = gca;
axis([-3 5 -3 5])
ax.XTick=[-1.96 0 1.96];
ax.YTick=[-1.96 0 1.96];
line([-3 5],[-3,5],'Color',GREY);
line([-3 5],[critval critval],'Color',GREY);
line([-3 5],[-critval -critval],'Color',GREY);
line([critval critval], [-3 5],'Color',GREY);
line([-critval -critval], [-3 5],'Color',GREY);

text(4,0,'A','FontSize',9);
text(0,4,'B','FontSize',9);

xlabel('Z','FontSize',9);
ylabel('Z^r','FontSize',9); 
axis square

print(fig,'-dpdf', '../../FiguresandTables/ReplicationIllustration.pdf')


%%
%Illustrating replication approach for slides
rng(seed)
X= Lambdastar + randn(n,1);
Xr = Lambdastar +   randn(n,1);
significant=(abs(X)>critval);
D=(rand(n,1) < 0.1 + 0.9 * significant);




fig=figure('Visible','on',...
      'PaperPosition',[0 0 13 6],...
      'PaperSize',[13 6])
subplot(1,2,1)
scatter(X(significant), Xr(significant), circlesize, BLUE,'filled');
    hold on;  
scatter(X(~significant), Xr(~significant), circlesize,SLIDE_GREY,'filled'); 

ax = gca;
axis([-3 5 -3 5])
ax.XTick=[-1.96 0 1.96];
ax.YTick=[-1.96 0 1.96];
line([-3 5],[-3,5],'Color',SLIDE_GREY);
line([-3 5],[critval critval],'Color',SLIDE_GREY);
line([-3 5],[-critval -critval],'Color',SLIDE_GREY);
line([critval critval], [-3 5],'Color',SLIDE_GREY);
line([-critval -critval], [-3 5],'Color',SLIDE_GREY);
xlabel('X^*');
ylabel('X^{r*}'); 
axis square

subplot(1,2,2)
scatter(X(significant), Xr(significant), circlesize, BLUE,'filled');
    hold on;  
scatter(X(~significant & D), Xr(~significant & D), circlesize,SLIDE_GREY,'filled');  
ax = gca;
axis([-3 5 -3 5])
ax.XTick=[-1.96 0 1.96];
ax.YTick=[-1.96 0 1.96];
line([-3 5],[-3,5],'Color',SLIDE_GREY);
line([-3 5],[critval critval],'Color',SLIDE_GREY);
line([-3 5],[-critval -critval],'Color',SLIDE_GREY);
line([critval critval], [-3 5],'Color',SLIDE_GREY);
line([-critval -critval], [-3 5],'Color',SLIDE_GREY);

text(4,0,'A','FontSize',18);
text(0,4,'B','FontSize',18);

xlabel('X');
ylabel('X^r'); 
axis square

print(fig,'-dpdf', '../../FiguresandTables/ReplicationIllustrationSlides.pdf')
%%
%Illustrating variation in variance approach
rng(seed)
X= Lambdastar+sigma.*randn(n,1);

significant=(abs(X./sigma)>critval);
D=(rand(n,1) < 0.1 + 0.9 * significant);


fig=figure('Visible','on',...
      'PaperPosition',[0 0 6 2.5],...
      'PaperSize',[6 2.5])
subplot(1,2,1)
scatter(X(significant), sigma(significant), circlesize_paper, BLUE,'filled');
    hold on;  
scatter(X(~significant), sigma(~significant), circlesize_paper, GREY,  'filled'); 
axis([-3 5 0 2.5])
line([0, 5],[0, 5/critval],'Color',GREY);
line([-3,0],[3/critval,0],'Color',GREY);
line([-3 5],[0.5 0.5],'Color',GREY);
line([-3 5],[1 1],'Color',GREY);
xlabel('X^*','FontSize',9);
ylabel('\Sigma^*','FontSize',9); 
axis square

subplot(1,2,2)
scatter(X(significant), sigma(significant), circlesize_paper, BLUE,'filled');
    hold on;  
scatter(X(~significant & D), sigma(~significant & D), circlesize_paper, GREY,  'filled');  
axis([-3 5 0 2.5])
line([0, 5],[0, 5/critval],'Color',GREY);
line([-3,0],[3/critval,0],'Color',GREY);
line([-3 5],[0.5 0.5],'Color',GREY);
line([-3 5],[1 1],'Color',GREY);
text(5,0.5,'A','FontSize',9);
text(5,1,'B','FontSize',9);
xlabel('X','FontSize',9);
ylabel('\Sigma','FontSize',9); 
axis square

% text(4,0,'A');
% text(0,4,'B');



print(fig,'-dpdf', '../../FiguresandTables/VariationSigmaIllustration.pdf')


%%
%Illustrating variation in variance approach for slides
rng(seed)
X= Lambdastar+sigma.*randn(n,1);

significant=(abs(X./sigma)>critval);
D=(rand(n,1) < 0.1 + 0.9 * significant);


fig=figure('Visible','on',...
      'PaperPosition',[0 0 13 6],...
      'PaperSize',[13 6])
subplot(1,2,1)
scatter(X(significant), sigma(significant), circlesize, BLUE,'filled');
    hold on;  
scatter(X(~significant), sigma(~significant), circlesize, SLIDE_GREY,  'filled'); 
axis([-3 5 0 2.5])
line([0, 5],[0, 5/critval],'Color',SLIDE_GREY,'linewidth',1.5);
line([-3,0],[3/critval,0],'Color',SLIDE_GREY,'linewidth',1.5);
line([-3 5],[0.5 0.5],'Color',SLIDE_GREY,'linewidth',1.5);
line([-3 5],[1 1],'Color',SLIDE_GREY,'linewidth',1.5);
xlabel('X^*');
ylabel('\Sigma^*'); 
axis square

subplot(1,2,2)
scatter(X(significant), sigma(significant), circlesize, BLUE,'filled');
    hold on;  
scatter(X(~significant & D), sigma(~significant & D), circlesize, SLIDE_GREY,  'filled');  
axis([-3 5 0 2.5])
line([0, 5],[0, 5/critval],'Color',SLIDE_GREY,'linewidth',1.5);
line([-3,0],[3/critval,0],'Color',SLIDE_GREY,'linewidth',1.5);
line([-3 5],[0.5 0.5],'Color',SLIDE_GREY,'linewidth',1.5);
line([-3 5],[1 1],'Color',SLIDE_GREY,'linewidth',1.5);
text(5,0.5,'A','FontSize',18);
text(5,1,'B','FontSize',18);
xlabel('X');
ylabel('\Sigma'); 
axis square

% text(4,0,'A');
% text(0,4,'B');



print(fig,'-dpdf', '../../FiguresandTables/VariationSigmaIllustrationSlides.pdf')




