clear
theta_grid=-10:.01:10;
a=1;
b=-0.9;
x_L=-1.96;
x_U=1.96;
sigma=1;
xgrid=0:.01:5;
alpha=0.05;

Theta_U_store=zeros(length(xgrid),1);
Theta_L_store=zeros(length(xgrid),1);
Theta_M_store=zeros(length(xgrid),1);
for n=1:length(xgrid)
    X=xgrid(n);
    
    g_U=@(theta)(alpha/2-Interval_truncation_normal_cdf(X,theta,sigma,a,b,x_L,x_U)).^2;
    g_L=@(theta)(1-alpha/2-Interval_truncation_normal_cdf(X,theta,sigma,a,b,x_L,x_U)).^2;
    g_M=@(theta) (1/2-Interval_truncation_normal_cdf(X,theta,sigma,a,b,x_L,x_U)).^2;
    
    theta_U=fminsearch(g_U,X);
    theta_L=fminsearch(g_L,X);
    theta_M=fminsearch(g_M,X);
    
    Theta_U_store(n)=theta_U;
    Theta_L_store(n)=theta_L;
    Theta_M_store(n)=theta_M;
end

likelihood_store=zeros(length(theta_grid),length(xgrid));
for n1=1:length(theta_grid)
    theta=theta_grid(n1);
    for n2=1:length(xgrid)
        X=xgrid(n2);
        likelihood_store(n1,n2)=Interval_truncation_normal_pdf(X,theta,sigma,a,b,x_L,x_U);
    end
end

for n=1:size(likelihood_store,2)
    likelihood_store(:,n)=likelihood_store(:,n)/sum(likelihood_store(:,n));
end

%Calculate posterior mean and variance under a flat prior
posterior_mean=sum(repmat(theta_grid',1,size(likelihood_store,2)).*likelihood_store);
temp=sum(repmat(theta_grid',1,size(likelihood_store,2)).^2.*likelihood_store);
posterior_variance=temp-posterior_mean.^2;

for n=1:size(likelihood_store,2)
    sum_dummy=cumsum(likelihood_store(:,n))>=0.5;
    temp=theta_grid(sum_dummy);
    posterior_median(1,n)=temp(1);
    
    sum_dummy=cumsum(likelihood_store(:,n))>=0.025;
    temp=theta_grid(sum_dummy);
    posterior_lower025(1,n)=temp(1);
    
    sum_dummy=cumsum(likelihood_store(:,n))>=0.975;
    temp=theta_grid(sum_dummy);
    posterior_upper025(1,n)=temp(1);
    
    temp=-sort(-likelihood_store(:,n));
    sum_dummy=cumsum(temp)>=0.95;
    temp=temp(sum_dummy);
    cutoff=temp(1);
    temp=theta_grid(likelihood_store(:,n)>=cutoff);
    HPD_lower(1,n)=temp(1);
    HPD_upper(1,n)=temp(end);
    temp=theta_grid(likelihood_store(:,n)==max(likelihood_store(:,n)));
    posterior_mode(1,n)=temp(1);
end

%%

fig=figure('Visible','on',...
      'PaperPosition',[0 0 8 6],...
      'PaperSize',[8 6])
  
plot(xgrid',[xgrid'-1.96],'Color',[.6 .6 .6],'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',[.6 .6 .6],'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',[.6 .6 .6],'Linewidth',1.5)

p1=plot(xgrid',[posterior_lower025], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ posterior_median ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[posterior_upper025], 'Color',[.4 .4 .8],'Linewidth',1.5)

hold off
legend([p1,p2], {'Lower/Upper 95% Credible Bound','Posterior Median'},'Location','NW')
xlabel('X','Fontsize',16)
ylabel('Estimated \theta','Fontsize',16)

%%
print(fig,'-dpdf', '../../../FiguresandTables/Interval_truncated_credible_bounds_slides.pdf')

%%
fig=figure('Visible','on',...
      'PaperPosition',[0 0 8 6],...
      'PaperSize',[8 6])
  
plot(xgrid',[xgrid'-1.96],'Color',[.8 .8 .8],'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',[.8 .8 .8],'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',[.8 .8 .8],'Linewidth',1.5)

p1=plot(xgrid',[posterior_lower025], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ posterior_median ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[posterior_upper025], 'Color',[.4 .4 .8],'Linewidth',1.5)

hold off
legend([p1,p2], {'Lower/Upper 95% Credible Bound','Posterior Median'},'Location','NW')
xlabel('X','Fontsize',16)
ylabel('Estimated \theta','Fontsize',16)

%%
print(fig,'-dpdf', '../../../FiguresandTables/Interval_truncated_credible_bounds.pdf')

%%
%%Used in paper
GREY=[.7 .7 .7];

fig=figure('Visible','on',...
    'PaperPosition',[0 0 4 4],...
    'PaperSize',[4 4])

plot(xgrid',[xgrid'-1.96],'Color',GREY,'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',GREY,'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',GREY,'Linewidth',1.5)

xmin=min(xgrid);
xmax=max(xgrid);

ymin=min(Theta_L_store,xmin-1.96);
ymax=max(Theta_U_store,xmax+1.96);

for n=ceil(xmin)+1:1:floor(xmax)-1
    line([n n],[ymin ymax],'LineStyle',':','Color',GREY,'Linewidth',1)
end

for n=ceil(ymin):1:floor(ymax)
    line([xmin xmax],[n n],'LineStyle',':','Color',GREY,'Linewidth',1)
end

p1=plot(xgrid',[Theta_L_store], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ Theta_M_store ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[Theta_U_store], 'Color',[.4 .4 .8],'Linewidth',1.5)

hold off
legend([p1,p2], {'95% Confidence Bounds','Median Unbiased Estimator'},'Location','N','Fontsize',9)
xlabel('X','Fontsize',9)
ylabel('Estimated \theta','Fontsize',9)
axis square tight

%%
print(fig,'-dpdf', '../../../FiguresandTables/Interval_truncated_confidence_bounds.pdf')

%%
GREY=[.7 .7 .7];

fig=figure('Visible','on',...
    'PaperPosition',[0 0 4 4],...
    'PaperSize',[4 4])

plot(xgrid',[xgrid'-1.96],'Color',GREY,'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',GREY,'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',GREY,'Linewidth',1.5)

xmin=min(xgrid);
xmax=max(xgrid);

ymin=min(Theta_L_store,xmin-1.96);
ymax=max(Theta_U_store,xmax+1.96);

for n=ceil(xmin)+1:1:floor(xmax)-1
    line([n n],[ymin ymax],'LineStyle',':','Color',GREY,'Linewidth',1)
end

for n=ceil(ymin):1:floor(ymax)
    line([xmin xmax],[n n],'LineStyle',':','Color',GREY,'Linewidth',1)
end

p1=plot(xgrid',[Theta_L_store], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ Theta_M_store ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[Theta_U_store], 'Color',[.4 .4 .8],'Linewidth',1.5)
hold off
legend([p1,p2], {'95% Confidence Bounds','Median Unbiased Estimator'},'Location','NE','Fontsize',9)
xlabel('X','Fontsize',9)
ylabel('Estimated \theta','Fontsize',9)
axis square tight

%%
print(fig,'-dpdf', '../../../FiguresandTables/Interval_truncated_confidence_bounds_square.pdf')


%%
%plot with darker colors for slides
fig=figure('Visible','on',...
      'PaperPosition',[0 0 8 6],...
      'PaperSize',[8 6])
  
plot(xgrid',[xgrid'-1.96],'Color',[.6 .6 .6],'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',[.6 .6 .6],'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',[.6 .6 .6],'Linewidth',1.5)

p1=plot(xgrid',[Theta_L_store], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ Theta_M_store ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[Theta_U_store], 'Color',[.4 .4 .8],'Linewidth',1.5)

hold off
legend([p1,p2], {'Lower/Upper 95% Confidence Bound','Median Unbiased Estimator'},'Location','NW')
xlabel('X','Fontsize',16)
ylabel('Estimated \theta','Fontsize',16)
%axis equal tight

%%
print(fig,'-dpdf', '../../../FiguresandTables/Interval_truncated_confidence_bounds_slides.pdf')

%%
fig=figure('Visible','on',...
      'PaperPosition',[0 0 10 4],...
      'PaperSize',[10 4])
  
subplot(1,2,1)
plot(xgrid',[xgrid'-1.96],'Color',[.8 .8 .8])
hold on
plot(xgrid',[ xgrid ],'Color',[.8 .8 .8])
plot(xgrid',[xgrid'+1.96],'Color',[.8 .8 .8])

p1=plot(xgrid',[Theta_L_store], 'Color',[.4 .4 .8],'Linewidth',1)
p2=plot(xgrid',[ Theta_M_store ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[Theta_U_store], 'Color',[.4 .4 .8],'Linewidth',1)

hold off
legend([p1,p2], {'Lower/Upper 95% Confidence Bound','Median Unbiased Estimator'},'Location','NW')
xlabel('X','Fontsize',12)
ylabel('Estimated \theta','Fontsize',12)

subplot(1,2,2)
plot(xgrid',[xgrid'-1.96],'Color',[.8 .8 .8],'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',[.8 .8 .8],'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',[.8 .8 .8],'Linewidth',1.5)

p1=plot(xgrid',[posterior_lower025], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ posterior_median ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[posterior_upper025], 'Color',[.4 .4 .8],'Linewidth',1.5)

hold off
legend([p1,p2], {'Lower/Upper 95% Credible Bound','Posterior Median'},'Location','NW')
xlabel('X','Fontsize',12)
ylabel('Estimated \theta','Fontsize',12)

%%
print(fig,'-dpdf', '../../../FiguresandTables/Interval_truncated_combined_bounds_slides.pdf')

%%

fig2=figure('Visible','on',...
      'PaperPosition',[0 0 8 6],...
      'PaperSize',[8 6])
  
plot(xgrid',[xgrid'-1.96],'Color',[.6 .6 .6],'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',[.6 .6 .6],'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',[.6 .6 .6],'Linewidth',1.5)

p1=plot(xgrid',[HPD_lower], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ posterior_mode ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[HPD_upper], 'Color',[.4 .4 .8],'Linewidth',1.5)

hold off
legend([p1,p2], {'Lower/Upper 95% Credible Bound','Posterior Mode'},'Location','NW')
xlabel('X','Fontsize',16)
ylabel('Estimated \theta','Fontsize',16)

