function [LLH, logL] = ...
    ReplicationAnalyticLogLikelihoodControls(nuhat, tauhat, betap, cutoffs, symmetric, Z, sigmaZ2,C,numerical_integration)
%arguments: mean and stdev of distribution pi of mu
%coefficient vector for step function p, in increasing order
%vector of thresholds for step function p, in increasing order
%dummy for symmetric step function: if one, all cutoffs should be positive
%n by 2 matrix of estimates
%vector of stdevs of X2
%matrix of control variables

n=length(Z(:,1));
k=length(betap(:,1));

%%%create step function
Z1_dummies=zeros(n,length(cutoffs)+1);
if symmetric==1
    Z1_dummies(:,1)=abs(Z(:,1))<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Z1_dummies(:,m)=(abs(Z(:,1))<cutoffs(m)).*(abs(Z(:,1))>=cutoffs(m-1));
        end
    end
    Z1_dummies(:,end)=abs(Z(:,1))>=cutoffs(end);
else
    Z1_dummies(:,1)=Z(:,1)<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Z1_dummies(:,m)=(Z(:,1)<cutoffs(m)).*(Z(:,1)>=cutoffs(m-1));
        end
    end
    Z1_dummies(:,end)=Z(:,1)>=cutoffs(end);
end

%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate objective function LLH

%calculating components of the likelihood
%vector of estimated publication probabilities
phat=zeros(size(Z1_dummies,1),1);
for m=1:size(Z1_dummies,2)
    Cmat=repmat(Z1_dummies(:,m),1,size(C,2)).*C;
    phat=phat+Cmat*betap(:,m);
end



if symmetric==1
%     %likelihoods calculated by numerical integration, normal distribution
%     g=@(theta) (0.5*normpdf(Z(:,1)-theta)+0.5*normpdf(-Z(:,1)-theta))...
%         .*normpdf((Z(:,2)-theta)./sigmaZ2)./sigmaZ2.*normpdf(theta,nuhat,tauhat);

if numerical_integration==1
%     %likelihoods calculated by numerical integration, gamma distribution
     g=@(theta) (0.5*normpdf(Z(:,1)-theta)+0.5*normpdf(-Z(:,1)-theta))...
         .*normpdf((Z(:,2)-theta)./sigmaZ2)./sigmaZ2.*gampdf(theta,nuhat,tauhat);
%     
     piZ1Z2=integral(g,-inf,inf,'Arrayvalued',true);
else  
    %Monte-carlo integration
    rng(1)
    draw=rand(1,10^5);
    theta_vec=gaminv(draw,nuhat,tauhat);
    theta_mat=repmat(theta_vec,n,1);
    Z1mat=repmat(Z(:,1),1,length(theta_vec));
    Z2mat=repmat(Z(:,2),1,length(theta_vec));
    sigmaZ2mat=repmat(sigmaZ2,1,length(theta_vec));
    g= (0.5*normpdf(Z1mat-theta_mat)+0.5*normpdf(-Z1mat-theta_mat))...
         .*normpdf((Z2mat-theta_mat)./sigmaZ2mat)./sigmaZ2mat;
     clear Z1mat Z2mat sigmaZ2mat theta_mat
     piZ1Z2=mean(g,2);
end
else
    %likelihoods calculated analytically, normal distribution
    piZ1Z2=zeros(n,1); %vector of un-truncated likelihoods
    for i=1:n
        Omega=[1+tauhat^2,tauhat^2;tauhat^2,sigmaZ2(i)^2+tauhat^2];
        piZ1Z2(i)=0.5*mvnpdf([Z(i,1), Z(i,2)],nuhat,Omega)...
            +0.5*mvnpdf([Z(i,1), Z(i,2)],-nuhat,Omega);
    end
    
end


%normalizing constant


prob_vec=zeros(length(cutoffs)+1,1);
if symmetric==1
    for m=1:length(cutoffs)
%                 prob_vec(m+1)=0.5*(normcdf((cutoffs(m)-mu)/sigma)-normcdf((-cutoffs(m)-mu)/sigma)) +...
%                     0.5*(normcdf((cutoffs(m)+mu)/sigma)-normcdf((-cutoffs(m)+mu)/sigma));
  
% %Normalizing constant assuming normal distribution for true effects   
% g=@(theta) (normcdf(cutoffs(m)-theta)-normcdf(-cutoffs(m)-theta))...
%             .*normpdf(theta,nuhat,tauhat);
        
 if numerical_integration==1   
    %Normalizing constant assuming gamma distribution for true effects   
    g=@(theta) (normcdf(cutoffs(m)-theta)-normcdf(-cutoffs(m)-theta))...
            .*gampdf(theta,nuhat,tauhat);
    
    prob_vec(m+1)=integral(g,-cutoffs(m)-5,cutoffs(m)+5,'Arrayvalued',true);
    %prob_vec(m+1)=integral(g,-inf,inf,'Arrayvalued',true);
 else
    %Monte Carlo Integration
    g=(normcdf(cutoffs(m)-theta_vec)-normcdf(-cutoffs(m)-theta_vec));
    prob_vec(m+1)=mean(g);
 end
     end

     prob_vec(end+1,1)=1;
    mean_Z1=prob_vec(2:end,1)-prob_vec(1:end-1,1);
else
    %calculate probability that T statistic based on X_i has absolute value
%less than critval
    mu=nuhat;
sigma=sqrt(tauhat.^2+1);
    for m=1:length(cutoffs)
        prob_vec(m+1)=0.5*normcdf((cutoffs(m)-mu)/sigma)+0.5*normcdf((cutoffs(m)+mu)/sigma);
    end
    prob_vec(end+1,1)=1;
    mean_Z1=prob_vec(2:end,1)-prob_vec(1:end-1,1);
end

normalizingconst=zeros(size(Z1_dummies,1),1);
for m=1:size(Z1_dummies,2)
    Cmat=mean_Z1(m,1)*C;
    normalizingconst=normalizingconst+Cmat*betap(:,m);
end


%vector of likelihoods
L=phat.*piZ1Z2./normalizingconst;
logL=log(L);

LLH=-sum(log(L)); %objective function; note the sign flip, since we are doing minimization
end