function moments = ReplicationMoments(betap, cutoffs, symmetric, Z, sigmaZ2,momentchoice)
%Calculate GMM moments for replication applications

n=length(Z(:,1));
k=length(betap);
betap=betap';

%%%create step function publication probability
Z1_dummies=zeros(n,length(cutoffs)+1);
if symmetric==1
    Z1_dummies(:,1)=abs(Z(:,1))<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Z1_dummies(:,m)=(abs(Z(:,1))<cutoffs(m)).*(abs(Z(:,1))>=cutoffs(m-1));
        end
    end
    Z1_dummies(:,end)=abs(Z(:,1))>=cutoffs(end);
else
    Z1_dummies(:,1)=Z(:,1)<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Z1_dummies(:,m)=(Z(:,1)<cutoffs(m)).*(Z(:,1)>=cutoffs(m-1));
        end
    end
    Z1_dummies(:,end)=Z(:,1)>=cutoffs(end);
end

phat=Z1_dummies*betap; %vector of estimated publication probabilities, step function model

%%%create moments for latent variables
if momentchoice==1
sigma_max=max(max(sigmaZ2),1);
sigma_adj1=(sigma_max^2-1).^.5;
sigma_adj2=(sigma_max^2-sigmaZ2.^2).^.5;
if symmetric==1
    if length(cutoffs)==1
        c=cutoffs;
        lmoment1=(normcdf((c-Z(:,1))./sigma_adj1)-normcdf((-c-Z(:,1))./sigma_adj1));
        lmoment2=(normcdf((c-Z(:,2))./sigma_adj2)-normcdf((-c-Z(:,2))./sigma_adj2));
        lmoments=lmoment1.*(1-lmoment2)-lmoment2.*(1-lmoment1);
    elseif length(cutoffs)==2
        c1=cutoffs(1);
        lmoment1=(normcdf((c1-Z(:,1))./sigma_adj1)-normcdf((-c1-Z(:,1))./sigma_adj1));
        lmoment2=(normcdf((c1-Z(:,2))./sigma_adj2)-normcdf((-c1-Z(:,2))./sigma_adj2));
        
        c2=cutoffs(2);
        lmoment3=(normcdf((c2-Z(:,1))./sigma_adj1)-normcdf((-c2-Z(:,1))./sigma_adj1));
        lmoment4=(normcdf((c2-Z(:,2))./sigma_adj2)-normcdf((-c2-Z(:,2))./sigma_adj2));
        
        lmoments(:,1)=lmoment1.*(1-lmoment2)-lmoment2.*(1-lmoment1);
        lmoments(:,2)=lmoment3.*(1-lmoment4)-lmoment4.*(1-lmoment3); 
        lmoments(:,3)=lmoment1.*(1-lmoment4)-lmoment2.*(1-lmoment3);
        lmoments(:,4)=lmoment3.*(1-lmoment2)-lmoment4.*(1-lmoment1);
    end
end
elseif momentchoice==2
    if symmetric==1
    for k=1:length(cutoffs)
        lmoments(:,k)=(Z(:,1).^2-1)-(Z(:,2).^2-sigmaZ2.^2);
    end
end
end
moments=lmoments./repmat(phat,1,size(lmoments,2));

end

