function [LLH, logL] = ...
    ReplicationpzthetaLogLikelihood(nuhat, tauhat, betap, gammap, cutoffs,...
    symmetric, Z, sigmaZ2, vcutoff)

%arguments: mean and stdev of distribution pi of mu
%coefficient vector beta for specification of p, in increasing order
%coefficient vector gamma for specification of p, in increasing order
%vector of thresholds for step function p, in increasing order
%dummy for symmetric step function: if one, all cutoffs should be positive
%n by 2 matrix of estimates
%vector of stdevs of X2
%cutoff for latent variable V in specification of p
%simulation draws for z
%simulation draws for theta
%standard deviation of z simulation draws
%standard deviation of theta simulation draws

zdrawcount=5*10^3;
thetadrawcount=5*10^3;

n=length(Z(:,1));
nz=zdrawcount;
ntheta=thetadrawcount;
k=length(betap);
betap=betap';
gammap=gammap';

zdrawsd=5;
rng(1)
Zdraws=randn(zdrawcount,1)*zdrawsd;
Thetadraws=rand(thetadrawcount,1);
Thetadraws=gaminv(Thetadraws,nuhat,tauhat);

%calculate p(z,theta) with elementwise operations
if symmetric==1
    if k==2
        pztheta=@(z,theta) (abs(z)<cutoffs(1)).*(betap(1)-(normcdf(vcutoff-theta)-normcdf(-vcutoff-theta))*gammap(1))...
            +(abs(z)>=cutoffs(1)).*(betap(2)-(normcdf(vcutoff-theta)-normcdf(-vcutoff-theta))*gammap(2));
    elseif k==3
        pztheta=@(z,theta)  (abs(z)<cutoffs(1)).*(betap(1)-(normcdf(vcutoff-theta)-normcdf(-vcutoff-theta))*gammap(1))...
            +(abs(z)>=cutoffs(1)&abs(z)<cutoffs(2)).*(betap(2)-(normcdf(vcutoff-theta)-normcdf(-vcutoff-theta))*gammap(2))...
            +(abs(z)>=cutoffs(2)).*(betap(3)-(normcdf(vcutoff-theta)-normcdf(-vcutoff-theta))*gammap(3));
    else
        error('code only specified for 1 or 2 cutoffs')
    end
else
    error('code only specified for symmetric case')
end

%Simplifying exponents for numerical precision
Zdrawmat=repmat(Zdraws(:,1),1,ntheta);
Thetadrawmat=repmat(Thetadraws(:,1)',nz,1);
denominator=mean(mean(...
    pztheta(Zdrawmat,Thetadrawmat)...
    .*exp(-0.5*(1-zdrawsd^-2)*Zdrawmat.^2+...
    Zdrawmat.*Thetadrawmat-0.5*Thetadrawmat.^2)...
    *zdrawsd));

Z1mat=repmat(Z(:,1),1,ntheta);
Z2mat=repmat(Z(:,2),1,ntheta);
sigmamat=repmat(sigmaZ2,1,ntheta);
Thetadrawmat=repmat(Thetadraws(:,1)',n,1);
numerator=mean(pztheta(Z1mat,Thetadrawmat)...
    .*exp(-0.5*Z1mat.^2+Z1mat.*Thetadrawmat-0.5*Thetadrawmat.^2)...
    .*normpdf((Z2mat-Thetadrawmat)./sigmamat)./sigmamat,2);

logL=log(numerator/denominator);
LLH=-sum(logL); %objective function; note the sign flip, since we are doing minimization
end