function [LLH, logL] = VariationVarianceLogLikelihoodtdist_logit(lambdabar, tauhat, nuhat, betap, cutoffs, symmetric, X, sigma,C,numerical_integration,enforce_boundary)

%arguments: mean and stdev of distribution pi of mu
%coefficient vector for polynomial logit p
%n vector X of estimates
%vector of stdevs of X

n=length(X);
logistic=@(p) exp(p)./(1+exp(p));

%regressors for step function p
T=X./sigma;

Tpowers=zeros(n,length(cutoffs)+1);
if symmetric==1
    Tpowers(:,1)=abs(T)<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Tpowers(:,m)=(abs(T)<cutoffs(m)).*(abs(T)>=cutoffs(m-1));
        end
    end
    Tpowers(:,end)=abs(T)>=cutoffs(end);
else
    Tpowers(:,1)=T<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Tpowers(:,m)=(T<cutoffs(m)).*(T>=cutoffs(m-1));
        end
    end
    Tpowers(:,end)=T>=cutoffs(end);
end

%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate objective function LLH

%calculating components of the likelihood
%vector of estimated publication probabilities
phat=zeros(size(Tpowers,1),1);
for m=1:size(Tpowers,2)
    Cmat=repmat(Tpowers(:,m),1,size(C,2)).*C;
    phat=phat+Cmat*betap(:,m);
end
phat=logistic(phat);

%vector of un-truncated likelihoods
if numerical_integration==1
    g=@(theta) normpdf((X-theta)./sigma)./sigma...
        .*tpdf((theta-lambdabar)/tauhat,nuhat)/tauhat;
    fX=integral(g,-inf,inf,'Arrayvalued',true);
else
    rng(1)
    draw=rand(1,10^4);
    theta_vec=tinv(draw,nuhat)*tauhat+lambdabar;
    theta_mat=repmat(theta_vec,n,1);
    X_mat=repmat(X,1,length(theta_vec));
    sigma_mat=repmat(sigma,1,length(theta_vec));
    g= normpdf((X_mat-theta_mat)./sigma_mat)...
        ./sigma_mat;
    clear Xmat
    fX=mean(g,2);
end

%normalizing constant
prob_vec=zeros(n,length(cutoffs)+1);

%Normalizing constant, t distribution
for m=1:length(cutoffs)
    if numerical_integration==1
        g=@(theta)normcdf(cutoffs(m)-theta./sigma)...
            .*tpdf((theta-lambdabar)/tauhat,nuhat)/tauhat;
        prob_vec(:,m+1)=integral(g,-inf,inf,'Arrayvalued',true);
    else
        g=normcdf(cutoffs(m)-theta_mat./sigma_mat);
        prob_vec(:,m+1)=mean(g,2);
    end
end
prob_vec(:,end+1)=1;
mean_Z1=prob_vec(:,2:end)-prob_vec(:,1:end-1);

normalizingconst=zeros(n,1);
for m=1:size(mean_Z1,2)
    normalizingconst=normalizingconst+mean_Z1(:,m).*logistic(C*betap(:,m));
end

%vector of likelihoods
L=phat.*fX./normalizingconst; %cf equation 25 in the draft
logL=log(L);
LLH=-sum(log(L));
end